clear;
close all;
DATA = csvread('data8.csv');

time = DATA(:,1);
setpoint = DATA(:,2);
position = DATA(:,3);
pwm = DATA(:,4);


time = time/1000;
time = time - time(1);

% according to the Rover 5 datasheet, the encoders give 1000 counts per 3 wheel rotations.
% wheels have a diameter of D=6cm
D = 6;
K = 3*pi*D/1000;
position = K*position; % position in cemtimeters
setpoint = K*setpoint; % position in cemtimeters



ts = 50/1000;
t = transpose(time(1):ts:time(end));

p = interp1(time,position,t);
v = diff(p);
v = [v(1);v];

u = interp1(time,-pwm,t);

dataid = iddata(v,u,ts);
moe = oe(dataid, [1 1 1]);

G = d2c(moe);
s = zpk('s');
Gxu = G*1/s;
PID = pidtune(Gxu,'pid',0.2);
L = PID*Gxu;
T = L/(1+L);

f = figure(1);
set(f,'color','w');
subplot(2,1,1);
plot(time, setpoint,'r');
hold on;
plot(time, position);
xlabel('time (s)');
ylabel('position (cm)');
%
legend('setpoint','position');
subplot(2,1,2);
plot(time, -pwm);
xlabel('time (s)');
ylabel('pwm duty cycle');
